import React, { useEffect, useState, useRef } from 'react';
import { SafeAreaView, StatusBar, useColorScheme, Alert, View, StyleSheet, TouchableOpacity, Image, } from 'react-native';
import { WebView } from 'react-native-webview';
const FrontFinance = (props) => {
    const isDarkMode = (useColorScheme === null || useColorScheme === void 0 ? void 0 : useColorScheme()) === 'dark';
    const backgroundStyle = {
        backgroundColor: isDarkMode ? '#000000' : '#ffffff',
    };
    const [catalogLink, setCatalogLink] = useState(null);
    const [showWebView, setShowWebView] = useState(false);
    const [showNativeNavbar, setShowNativeNavbar] = useState(false);
    const webViewRef = useRef(null);
    useEffect(() => {
        var _a;
        if (props.url.length) {
            setCatalogLink(props.url);
            setShowWebView(true);
        }
        else {
            (_a = props.onError) === null || _a === void 0 ? void 0 : _a.call(props, 'Invalid iframeUrl');
        }
        return () => {
            setCatalogLink(null);
            setShowWebView(false);
        };
    }, [props]);
    const handleNavState = (event) => {
        if (event.url.endsWith('/broker-connect/catalog')) {
            setShowNativeNavbar(false);
        }
    };
    const handleMessage = (event) => {
        var _a, _b, _c, _d;
        const { type, payload } = JSON.parse(event.nativeEvent.data);
        if (type === 'close' || type === 'done') {
            (_a = props.onClose) === null || _a === void 0 ? void 0 : _a.call(props);
        }
        if (type === 'showClose') {
            showCloseAlert();
        }
        if (type === 'showNativeNavbar') {
            setShowNativeNavbar(payload);
        }
        if (type === 'brokerageAccountAccessToken') {
            (_b = props.onBrokerConnected) === null || _b === void 0 ? void 0 : _b.call(props, { accessToken: payload });
        }
        if (type === 'delayedAuthentication') {
            (_c = props.onBrokerConnected) === null || _c === void 0 ? void 0 : _c.call(props, { delayedAuth: payload });
        }
        if (type === 'transferFinished') {
            (_d = props.onTransferFinished) === null || _d === void 0 ? void 0 : _d.call(props, payload);
        }
    };
    const goBack = () => { var _a; return (_a = webViewRef === null || webViewRef === void 0 ? void 0 : webViewRef.current) === null || _a === void 0 ? void 0 : _a.goBack(); };
    const showCloseAlert = () => Alert.alert('Are you sure you want to exit?', 'Your progress will be lost.', [
        {
            text: 'Cancel',
            style: 'cancel',
        },
        { text: 'Exit', onPress: () => { var _a; return (_a = props.onClose) === null || _a === void 0 ? void 0 : _a.call(props); } },
    ]);
    return (<SafeAreaView style={{ flex: 1 }} testID={'front-finance-component'}>
      <StatusBar barStyle={isDarkMode ? 'light-content' : 'dark-content'} backgroundColor={backgroundStyle.backgroundColor}/>
      {showNativeNavbar && (<View testID={'native-navbar'} style={styles.navBarContainer}>
          <TouchableOpacity onPress={goBack} style={styles.navBarImgContainer}>
            <Image source={require('./assets/ic_back.png')} style={styles.navBarImgButton}/>
          </TouchableOpacity>

          <Image source={require('./assets/front_logo.png')} style={styles.navBarLogo}/>

          <TouchableOpacity onPress={showCloseAlert} style={styles.navBarImgContainer} testID={'close-button'}>
            <Image source={require('./assets/ic_close.png')} style={styles.navBarImgButton}/>
          </TouchableOpacity>
        </View>)}
      {showWebView && catalogLink && (<WebView testID={'webview'} ref={webViewRef} source={{ uri: catalogLink ? catalogLink : '' }} onMessage={handleMessage} javaScriptEnabled={true} onNavigationStateChange={handleNavState}/>)}
    </SafeAreaView>);
};
const styles = StyleSheet.create({
    navBarContainer: {
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        height: 64,
        paddingTop: 12,
        paddingStart: 6,
        paddingEnd: 8,
    },
    navBarImgContainer: {
        width: 40,
        height: 40,
        alignItems: 'center',
        justifyContent: 'center',
    },
    navBarImgButton: {
        width: 24,
        height: 24,
        resizeMode: 'contain',
    },
    navBarLogo: {
        height: 18,
        resizeMode: 'contain',
    },
});
export default FrontFinance;
